==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/AsyncCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescription } from "./AsyncCompletedEventArgsDescription";
/**
 * @hidden
 */
var AsyncCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AsyncCompletedEventArgsDescriptionMetadata, _super);
    function AsyncCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AsyncCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (AsyncCompletedEventArgsDescriptionMetadata.a == null) {
            AsyncCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AsyncCompletedEventArgsDescriptionMetadata.c(AsyncCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.g(AsyncCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AsyncCompletedEventArgsDescriptionMetadata.a);
    };
    AsyncCompletedEventArgsDescriptionMetadata.c = function (a) {
    };
    AsyncCompletedEventArgsDescriptionMetadata.d = function (a) {
        AsyncCompletedEventArgsDescriptionMetadata.b(a);
        a.u("AsyncCompletedEventArgs", function () { return new AsyncCompletedEventArgsDescription(); });
        a.t("AsyncCompletedEventArgs", AsyncCompletedEventArgsDescriptionMetadata.a);
    };
    AsyncCompletedEventArgsDescriptionMetadata.$t = markType(AsyncCompletedEventArgsDescriptionMetadata, 'AsyncCompletedEventArgsDescriptionMetadata');
    AsyncCompletedEventArgsDescriptionMetadata.a = null;
    return AsyncCompletedEventArgsDescriptionMetadata;
}(Base));
export { AsyncCompletedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AsyncCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescription } from "./AsyncCompletedEventArgsDescription";
/**
 * @hidden
 */
var AsyncCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AsyncCompletedEventArgsDescriptionMetadata, _super);
    function AsyncCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AsyncCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (AsyncCompletedEventArgsDescriptionMetadata.a == null) {
            AsyncCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AsyncCompletedEventArgsDescriptionMetadata.c(AsyncCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.j(AsyncCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AsyncCompletedEventArgsDescriptionMetadata.a);
    };
    AsyncCompletedEventArgsDescriptionMetadata.c = function (a) {
    };
    AsyncCompletedEventArgsDescriptionMetadata.d = function (a) {
        AsyncCompletedEventArgsDescriptionMetadata.b(a);
        a.aa("AsyncCompletedEventArgs", function () { return new AsyncCompletedEventArgsDescription(); });
        a.z("AsyncCompletedEventArgs", AsyncCompletedEventArgsDescriptionMetadata.a);
    };
    AsyncCompletedEventArgsDescriptionMetadata.$t = markType(AsyncCompletedEventArgsDescriptionMetadata, 'AsyncCompletedEventArgsDescriptionMetadata');
    AsyncCompletedEventArgsDescriptionMetadata.a = null;
    return AsyncCompletedEventArgsDescriptionMetadata;
}(Base));
export { AsyncCompletedEventArgsDescriptionMetadata };
